Class: Aws::BedrockAgentCoreControl::Waiters::MemoryCreated
- Inherits:
-
Object
- Object
- Aws::BedrockAgentCoreControl::Waiters::MemoryCreated
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-bedrockagentcorecontrol/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ MemoryCreated
constructor
A new instance of MemoryCreated.
-
#wait(params = {}) ⇒ Types::GetMemoryOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ MemoryCreated
Returns a new instance of MemoryCreated.
89 90 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 89
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
127 128 129 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 127 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetMemoryOutput
Returns a response object which responds to the following methods:
- #memory => Types::Memory
122 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 122
def wait: (
|