Class: Aws::BedrockAgentCoreControl::Waiters::PolicyActive

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentcorecontrol/waiters.rb,
sig/waiters.rbs

Overview

Wait until a Policy is active

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ PolicyActive

Returns a new instance of PolicyActive.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 24
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


140
141
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 140

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



184
185
186
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 184

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetPolicyResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :policy_engine_id (required, String)

    The identifier of the policy engine that manages the policy to be retrieved.

  • :policy_id (required, String)

    The unique identifier of the policy to be retrieved. This must be a valid policy ID that exists within the specified policy engine.

Returns:



179
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 179

def wait: (