Class: Aws::BedrockAgentCoreControl::Waiters::PolicyEngineActive
- Inherits:
-
Object
- Object
- Aws::BedrockAgentCoreControl::Waiters::PolicyEngineActive
- Defined in:
- lib/aws-sdk-bedrockagentcorecontrol/waiters.rb,
sig/waiters.rbs
Overview
Wait until a PolicyEngine is active
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PolicyEngineActive
constructor
A new instance of PolicyEngineActive.
-
#wait(params = {}) ⇒ Types::GetPolicyEngineResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PolicyEngineActive
Returns a new instance of PolicyEngineActive.
247 248 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 247
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
291 292 293 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 291 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPolicyEngineResponse
Returns a response object which responds to the following methods:
- #policy_engine_id => String
- #name => String
- #created_at => Time
- #updated_at => Time
- #policy_engine_arn => String
- #status => String
- #encryption_key_arn => String
- #description => String
- #status_reasons => Array<String>
286 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 286
def wait: (
|