Class: Aws::BedrockAgentCoreControl::Waiters::PolicyGenerationCompleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentcorecontrol/waiters.rb,
sig/waiters.rbs

Overview

Wait until policy generation is completed

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ PolicyGenerationCompleted

Returns a new instance of PolicyGenerationCompleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 24
  • :delay (Integer) — default: 5
  • :before_attempt (Proc)
  • :before_wait (Proc)


354
355
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 354

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



398
399
400
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 398

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetPolicyGenerationResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :policy_generation_id (required, String)

    The unique identifier of the policy generation request to be retrieved. This must be a valid generation ID from a previous StartPolicyGeneration call.

  • :policy_engine_id (required, String)

    The identifier of the policy engine associated with the policy generation request. This provides the context for the generation operation and schema validation.

Returns:



393
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 393

def wait: (