Class: Aws::BedrockAgentCoreControl::Waiters::MemoryCreated

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentcorecontrol/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MemoryCreated

Returns a new instance of MemoryCreated.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 2
  • :before_attempt (Proc)
  • :before_wait (Proc)


89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 89

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 2,
    poller: Aws::Waiters::Poller.new(
      operation_name: :get_memory,
      acceptors: [
        {
          "matcher" => "path",
          "argument" => "memory.status",
          "state" => "retry",
          "expected" => "CREATING"
        },
        {
          "matcher" => "path",
          "argument" => "memory.status",
          "state" => "success",
          "expected" => "ACTIVE"
        },
        {
          "matcher" => "path",
          "argument" => "memory.status",
          "state" => "failure",
          "expected" => "FAILED"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



127
128
129
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 127

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetMemoryOutput

Returns a response object which responds to the following methods:

Options Hash (params):

  • :memory_id (required, String)

    The unique identifier of the memory to retrieve.

  • :view (String)

    The level of detail to return for the memory.

Returns:



122
123
124
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 122

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end