Class: Aws::BedrockAgentCoreControl::Waiters::PolicyActive
- Inherits:
-
Object
- Object
- Aws::BedrockAgentCoreControl::Waiters::PolicyActive
- Defined in:
- lib/aws-sdk-bedrockagentcorecontrol/waiters.rb,
sig/waiters.rbs
Overview
Wait until a Policy is active
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PolicyActive
constructor
A new instance of PolicyActive.
-
#wait(params = {}) ⇒ Types::GetPolicyResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PolicyActive
Returns a new instance of PolicyActive.
140 141 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 140
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
184 185 186 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 184 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPolicyResponse
Returns a response object which responds to the following methods:
- #policy_id => String
- #name => String
- #policy_engine_id => String
- #created_at => Time
- #updated_at => Time
- #policy_arn => String
- #status => String
- #enforcement_mode => String
- #definition => Types::PolicyDefinition
- #description => String
- #status_reasons => Array<String>
179 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 179
def wait: (
|