Class: Aws::BedrockAgentCoreControl::Waiters::PolicyEngineDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-bedrockagentcorecontrol/waiters.rb

Overview

Wait until a PolicyEngine is deleted

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ PolicyEngineDeleted

Returns a new instance of PolicyEngineDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 2
  • :before_attempt (Proc)
  • :before_wait (Proc)


304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 304

def initialize(options)
  @client = options.fetch(:client)
  @waiter = Aws::Waiters::Waiter.new({
    max_attempts: 60,
    delay: 2,
    poller: Aws::Waiters::Poller.new(
      operation_name: :get_policy_engine,
      acceptors: [
        {
          "matcher" => "error",
          "state" => "success",
          "expected" => "ResourceNotFoundException"
        },
        {
          "matcher" => "path",
          "argument" => "status",
          "state" => "retry",
          "expected" => "DELETING"
        },
        {
          "matcher" => "path",
          "argument" => "status",
          "state" => "failure",
          "expected" => "DELETE_FAILED"
        }
      ]
    )
  }.merge(options))
end

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



341
342
343
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 341

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetPolicyEngineResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :policy_engine_id (required, String)

    The unique identifier of the policy engine to be retrieved. This must be a valid policy engine ID that exists within the account.

Returns:



336
337
338
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 336

def wait(params = {})
  @waiter.wait(client: @client, params: params)
end