Class: Aws::BedrockAgentCoreControl::Waiters::PolicyGenerationCompleted
- Inherits:
-
Object
- Object
- Aws::BedrockAgentCoreControl::Waiters::PolicyGenerationCompleted
- Defined in:
- lib/aws-sdk-bedrockagentcorecontrol/waiters.rb
Overview
Wait until policy generation is completed
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PolicyGenerationCompleted
constructor
A new instance of PolicyGenerationCompleted.
-
#wait(params = {}) ⇒ Types::GetPolicyGenerationResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PolicyGenerationCompleted
Returns a new instance of PolicyGenerationCompleted.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 354 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 24, delay: 5, poller: Aws::Waiters::Poller.new( operation_name: :get_policy_generation, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "GENERATED" }, { "matcher" => "path", "argument" => "status", "state" => "retry", "expected" => "GENERATING" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "GENERATE_FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "DELETE_FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
398 399 400 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 398 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPolicyGenerationResponse
Returns a response object which responds to the following methods:
-
#policy_engine_id => String
-
#policy_generation_id => String
-
#name => String
-
#policy_generation_arn => String
-
#resource => Types::Resource
-
#created_at => Time
-
#updated_at => Time
-
#status => String
-
#status_reasons => Array<String>
-
#findings => String
393 394 395 |
# File 'lib/aws-sdk-bedrockagentcorecontrol/waiters.rb', line 393 def wait(params = {}) @waiter.wait(client: @client, params: params) end |